//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Base/Axis/FrameTrafo.h
//! @brief     Defines class FrameTrafo.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_BASE_AXIS_FRAMETRAFO_H
#define BORNAGAIN_BASE_AXIS_FRAMETRAFO_H

#include <functional>
#include <string>
#include <vector>

class Coordinate;

using trafo_t = std::function<double(double)>;

//! One specific transform of frame coordinates.

class FrameTrafo {
public:
    ~FrameTrafo();
    FrameTrafo* clone() const;
    std::string name;
    std::vector<Coordinate> coords;
    std::vector<trafo_t> axTrafos;
    bool xMirror{false};
};

#endif // BORNAGAIN_BASE_AXIS_FRAMETRAFO_H
